import { Sheet, Tag } from "@prisma/client";
export declare type DataTag = {
    id?: number;
    category: string;
    value: string;
    categoryId?: number;
};
export declare type DataPoint = {
    tags: DataTag[];
    row: string;
    column: string;
    value: number | string | null;
    meta: number | string | null;
};
export declare type Datasheet = {
    id?: number;
    tags: DataTag[];
    columns: string[];
    rows: string[];
    data: (null[] | string[] | number[])[];
    meta: null | string[][];
};
export declare type TagWhereBySomeId = {
    tags: {
        some: {
            id: number;
        };
        AND?: TagWhereBySomeId;
    };
};
export declare type Sheets = (Sheet & {
    tags: Tag[];
})[];
export declare type DataPointFilterResult = {
    points: DataPoint[];
    label: string;
};
export declare type DataPointFilter = {
    (points: DataPoint[]): DataPointFilterResult;
};
export declare type DataGridFunction = {
    (tag: DataTag | string, key?: string): DataPointFilter;
};
export declare type DataGridCategories = {
    (keys: CellKeys): DataPointFilter[];
};
export declare type DataGrid = {
    rows: DataPointFilter[] | DataGridCategories;
    columns: DataPointFilter[] | DataGridCategories;
    cell(points: DataPoint[]): ResultCell;
};
export declare type CellKey = {
    [key: string]: boolean;
};
export declare type CellKeys = {
    [key: string]: CellKey;
};
export declare type ResultCell = number | string | null;
export declare type ResultRow = {
    [key: string]: ResultCell;
};
export declare type Result = {
    [key: string]: ResultRow;
};
